Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon FSx.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Amazon FSx - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for Amazon FSx

Amazon FSx (service prefix: `fsx` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon FSx
- Resource Types Defined by Amazon FSx
- Condition Keys for Amazon FSx

## Actions Defined by Amazon FSx

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CancelDataRepositoryTask | This action cancels a data repository task | Write | task* |  |
CreateBackup | This action creates a new backup. | Tagging | backup* |  |
file-system* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDataRepositoryTask | This action creates a new task. | Tagging | file-system* |  |
task* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFileSystem | This action creates a new, empty, Amazon FSx file system | Tagging | file-system* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFileSystemFromBackup | This action creates a new Amazon FSx file system from an existing backup. | Tagging | backup* |  |
file-system* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteBackup | This action deletes a backup, deleting its contents. After deletion, the backup no longer exists, and its data is gone. | Write | backup* |  |
DeleteFileSystem | This action deletes a file system, deleting its contents. | Write | file-system* |  |
DescribeBackups | This action returns the description of specific Amazon FSx backups, if one or more BackupIds are provided for that backup. Otherwise, it returns all backups owned by your AWS account in the AWS Region of the endpoint that you're calling. | Read |  |  |
DescribeDataRepositoryTasks | This action returns the description of specific Amazon FSx data repository task, if one or more TaskIds are provided for that data repository task. Otherwise, it returns all data repository task owned by your AWS account in the AWS Region of the endpoint that you're calling. | Read |  |  |
DescribeFileSystems | This action returns the description of specific Amazon FSx file systems, if a FileSystemIds value is provided for that file system. Otherwise, it returns descriptions of all file systems owned by your AWS account in the AWS Region of the endpoint that you're calling. | Read |  |  |
ListTagsForResource | This action lists tags for an Amazon FSx resource. | Read | backup |  |
file-system |  |
task |  |
TagResource | This action tags an Amazon FSx resource. | Tagging | backup |  |
file-system |  |
task |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | This action removes a tag from an Amazon FSx resource. | Tagging | backup |  |
file-system |  |
task |  |
| aws:TagKeys |
UpdateFileSystem | This action updates file system configuration. | Write | file-system* |  |

## Resource Types Defined by Amazon FSx

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Note

Amazon FSx for Windows File Server and Amazon FSx for Lustre share some of the same resource types, with the same ARN format for each.

Resource Types | ARN | Condition Keys
--- | --- | ---
file-system | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:file-system/*` | aws:ResourceTag/${TagKey}
backup | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:backup/*` | aws:ResourceTag/${TagKey}
task | `arn:$ { Partition}:fsx:$ { Region}:$ { Account}:task/*` | aws:ResourceTag/${TagKey}

## Condition Keys for Amazon FSx

Amazon FSx defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} |  | String
aws:ResourceTag/${TagKey} |  | String
aws:TagKeys |  | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.